@@ -61,7 +61,8 @@ class CompatTestCase(unittest.TestCase):
                 compile(gast.gast_to_ast(tree), '<test>', 'exec')
                 norm = ("Module(body=[Assign(targets=[Name(id='e', ctx=Store()"
                         ", annotation=None, type_comment=None"
-                        ")], value=Constant(value=1, kind=None)), Expr(value="
+                        ")], value=Constant(value=1, kind=None), "
+                        "type_comment=None), Expr(value="
                         "JoinedStr(values=[FormattedValue(value=Name(id='e', "
                         "ctx=Load(), annotation=None, type_comment=None), "
                         "conversion=-1, format_spec=None)]))], "
@@ -74,7 +75,8 @@ class CompatTestCase(unittest.TestCase):
                 compile(gast.gast_to_ast(tree), '<test>', 'exec')
                 norm = ("Module(body=[Assign(targets=[Name(id='e', ctx=Store()"
                         ", annotation=None, type_comment=None"
-                        ")], value=Constant(value=1, kind=None)), Expr(value="
+                        ")], value=Constant(value=1, kind=None), "
+                        "type_comment=None), Expr(value="
                         "JoinedStr(values=[Constant(value='e = ', kind=None), "
                         "FormattedValue(value=Name(id='e', ctx=Load(), "
                         "annotation=None, type_comment=None), "
@@ -96,6 +98,20 @@ class CompatTestCase(unittest.TestCase):
                         "[TypeIgnore(lineno=1, tag='[excuse]')])")
                 self.assertEqual(gast.dump(tree), norm)
 
+            def test_PosonlyArgs(self):
+                code = 'def foo(a, /, b): pass'
+                tree = gast.parse(code, type_comments=True)
+                compile(gast.gast_to_ast(tree), '<test>', 'exec')
+                norm = ("Module(body=[FunctionDef(name='foo', args=arguments("
+                        "args=[Name(id='b', ctx=Param(), annotation=None, "
+                        "type_comment=None)], posonlyargs=[Name(id='a', "
+                        "ctx=Param(), annotation=None, type_comment=None)], "
+                        "vararg=None, kwonlyargs=[], kw_defaults=[], "
+                        "kwarg=None, defaults=[]), body=[Pass()], "
+                        "decorator_list=[], returns=None, type_comment=None)"
+                        "], type_ignores=[])")
+                self.assertEqual(gast.dump(tree), norm)
+
         else:
 
             def test_Bytes(self):
@@ -238,12 +254,13 @@ class CompatTestCase(unittest.TestCase):
                 "], posonlyargs=[], vararg=None, kwonlyargs=[], kw_defaults=[]"
                 ", kwarg=None, defaults=[]), body=[Expr(value=Subscript(value="
                 "Name(id='a', ctx=Load(), annotation=None, type_comment=None)"
-                ", slice=Index(value=Constant(value=1, kind=None)), ctx=Load()"
+                ", slice=Constant(value=1, kind=None), ctx=Load()"
                 "))], decorator_list=[], returns=None, type_comment=None)]"
                 ", type_ignores=[])")
         self.assertEqual(gast.dump(tree), norm)
 
     def test_ExtSlice(self):
+        self.maxDiff = None
         code = 'def foo(a): a[:,:]'
         tree = gast.parse(code)
         compile(gast.gast_to_ast(tree), '<test>', 'exec')
@@ -252,13 +269,14 @@ class CompatTestCase(unittest.TestCase):
                 "], posonlyargs=[], vararg=None, kwonlyargs=[], kw_defaults=[]"
                 ", kwarg=None, defaults=[]), body=[Expr(value=Subscript(value="
                 "Name(id='a', ctx=Load(), annotation=None, type_comment=None)"
-                ", slice=ExtSlice(dims=[Slice(lower=None, upper=None, step="
-                "None), Slice(lower=None, upper=None, step=None)]), ctx=Load()"
-                "))], decorator_list=[], returns=None, type_comment=None)], "
-                "type_ignores=[])")
+                ", slice=Tuple(elts=[Slice(lower=None, upper=None, step="
+                "None), Slice(lower=None, upper=None, step=None)], ctx=Load())"
+                ", ctx=Load()))], decorator_list=[], returns=None, "
+                "type_comment=None)], type_ignores=[])")
         self.assertEqual(gast.dump(tree), norm)
 
     def test_ExtSlices(self):
+        self.maxDiff = None
         code = 'def foo(a): a[1,:]'
         tree = gast.parse(code)
         compile(gast.gast_to_ast(tree), '<test>', 'exec')
@@ -267,10 +285,10 @@ class CompatTestCase(unittest.TestCase):
                 "], posonlyargs=[], vararg=None, kwonlyargs=[], kw_defaults=[]"
                 ", kwarg=None, defaults=[]), body=[Expr(value=Subscript(value="
                 "Name(id='a', ctx=Load(), annotation=None, type_comment=None)"
-                ", slice=ExtSlice(dims=[Index(value=Constant(value=1, kind="
-                "None)), Slice(lower=None, upper=None, step=None)]), ctx=Load"
-                "()))], decorator_list=[], returns=None, type_comment=None)]"
-                ", type_ignores=[])")
+                ", slice=Tuple(elts=[Constant(value=1, kind="
+                "None), Slice(lower=None, upper=None, step=None)], ctx=Load())"
+                ", ctx=Load()))], decorator_list=[], returns=None, "
+                "type_comment=None)], type_ignores=[])")
         self.assertEqual(gast.dump(tree), norm)
 
     def test_Ellipsis(self):
@@ -283,8 +301,8 @@ class CompatTestCase(unittest.TestCase):
                 "], posonlyargs=[], vararg=None, kwonlyargs=[], kw_defaults=[]"
                 ", kwarg=None, defaults=[]), body=[Expr(value=Subscript(value="
                 "Name(id='a', ctx=Load(), annotation=None, type_comment=None)"
-                ", slice=Index(value=Constant(value=Ellipsis, kind=None)), ctx"
-                "=Load()))], decorator_list=[], returns=None, type_comment="
+                ", slice=Constant(value=Ellipsis, kind=None), ctx=Load()))], "
+                "decorator_list=[], returns=None, type_comment="
                 "None)], type_ignores=[])")
         self.assertEqual(gast.dump(tree), norm)
 
@@ -298,8 +316,8 @@ class CompatTestCase(unittest.TestCase):
                 "], posonlyargs=[], vararg=None, kwonlyargs=[], kw_defaults=[]"
                 ", kwarg=None, defaults=[]), body=[Expr(value=Subscript(value="
                 "Name(id='a', ctx=Load(), annotation=None, type_comment=None)"
-                ", slice=Index(value=Tuple(elts=[Constant(value=1, kind=None)"
-                ", Constant(value=Ellipsis, kind=None)], ctx=Load())), ctx="
+                ", slice=Tuple(elts=[Constant(value=1, kind=None)"
+                ", Constant(value=Ellipsis, kind=None)], ctx=Load()), ctx="
                 "Load()))], decorator_list=[], returns=None, type_comment="
                 "None)], type_ignores=[])")
         self.assertEqual(gast.dump(tree), norm)
